---
title: Footnotes
summary: Add footnotes to your documentation
external_links:
  Reference: https://python-markdown.github.io/extensions/footnotes/
---

## Syntax


```md
Footnotes[^1] have a label[^@#$%] and the footnote's content.

[^1]: This is a footnote content.
[^@#$%]: A footnote on the label: "@#$%".
```

Footnotes[^1] have a label[^@#$%] and the footnote's content.

[^1]: This is a footnote content.
[^@#$%]: A footnote on the label: "@#$%".